==> enstools-encoding-0.1.8.tar.gz: enstools-encoding-0.1.8/enstools/encoding/compressors/sz.py <==
import logging

from .compressor_class import Compressor
from .availability_checks import check_sz_availability
from ..errors import FilterNotAvailable

# The unique filter id given by HDF5
sz_filter_id = 32017


def sz_pack_error(error: float) -> int:
    from struct import pack, unpack
    return unpack('I', pack('<f', error))[0]  # Pack as IEEE 754 single


class SZ(Compressor):
    filter_id = sz_filter_id

    def __init__(self, abs=None, rel=None, pw_rel=None, chunksizes=None):
        # Check that a single option is selected:
        assert sum([abs is None, rel is None, pw_rel is None]) == 2, "Please select a single option."
        if not check_sz_availability():
            raise FilterNotAvailable("SZ filter is not available.")

        # Get SZ encoding options
        if abs is not None:
            sz_mode = 0
            parameter = abs
        elif rel is not None:
            sz_mode = 1
            parameter = rel
        elif pw_rel is not None:
            sz_mode = 10
            parameter = pw_rel
        else:
            raise NotImplementedError("One of the options need to be provided: abs, rel or pw_rel .")

        packed_error = sz_pack_error(parameter)
        compression_opts = (sz_mode, packed_error, packed_error, packed_error, packed_error)

        logging.info(f"SZ mode {sz_mode} used.")
        logging.info(f"filter options {compression_opts}")

        if chunksizes:
            # if compression_encoding:
            self.chunksizes = tuple(chunksizes)

        self.filter_options = compression_opts

==> enstools-encoding-0.1.10.tar.gz: enstools-encoding-0.1.10/enstools/encoding/compressors/sz.py <==
import logging

from .compressor_class import Compressor
from .availability_checks import check_sz_availability
from ..errors import FilterNotAvailable
from typing import Tuple
import struct

# The unique filter id given by HDF5
sz_filter_id = 32017


def sz_pack_error(error: float) -> Tuple[int, int]:
    from struct import pack, unpack
    packed = pack('<d', error)  # Pack as IEEE 754 double
    high = unpack('<I', packed[0:4])[0]  # Unpack high bits as unsigned int
    low = unpack('<I', packed[4:8])[0]
    return low,high


class SZ(Compressor):
    filter_id = sz_filter_id

    def __init__(self, abs=None, rel=None, pw_rel=None, chunksizes=None):
        # Check that a single option is selected:
        assert sum([abs is None, rel is None, pw_rel is None]) == 2, "Please select a single option."
        if not check_sz_availability():
            raise FilterNotAvailable("SZ filter is not available.")

        # Get SZ encoding options
        if abs is not None:
            sz_mode = 0
            parameter = abs
        elif rel is not None:
            sz_mode = 1
            parameter = rel
        elif pw_rel is not None:
            sz_mode = 10
            parameter = pw_rel
        else:
            raise NotImplementedError("One of the options need to be provided: abs, rel or pw_rel .")

        packed_error = sz_pack_error(parameter)
        compression_opts = (sz_mode, *packed_error, *packed_error, *packed_error, *packed_error)

        logging.info(f"SZ mode {sz_mode} used.")
        logging.info(f"filter options {compression_opts}")

        if chunksizes:
            # if compression_encoding:
            self.chunksizes = tuple(chunksizes)

        self.filter_options = compression_opts
